# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-20 19:14
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0021_project_max_applies_from_roles'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='job',
            name='dates',
        ),
        migrations.AddField(
            model_name='jobdate',
            name='job',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='dates', to='ovp_projects.Job'),
        ),
        migrations.AlterField(
            model_name='jobdate',
            name='name',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name='Label'),
        ),
    ]



from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse

from ovp_projects.models import Job, JobDate

from .jobdate import JobDateAdmin, JobDateInline


class JobInline(admin.TabularInline):
	exclude = ['title']
	model = Job
	verbose_name = _('Job')
	verbose_name_plural = _('Job')

	#fields = ('edit_dates_link',)
	readonly_fields = ['edit_dates_link']

	def edit_dates_link(self, obj):
		edit_dates_url = reverse("admin:{}_{}_change".format(obj._meta.app_label, obj._meta.model_name), args=(obj.id,))
		return '<a href="{}" target="_blank">{}</a>'.format(edit_dates_url, _('edit'))
	edit_dates_link.short_escription = _('Edit dates')
	edit_dates_link.allow_tags = True


class JobAdmin(admin.ModelAdmin):
	list_display = ['id', 'project', 'start_date', 'end_date']
	search_fields = ['id', 'project__name', 'project__nonprofit__name']

	inlines = (
		JobDateInline,
	)

admin.site.register(Job, JobAdmin)





from functools import wraps
from ovp_organizations.models import Organization

def hide_address(func):
  """ Used to decorate Serializer.to_representation method.
      It hides the address field if the Project has 'hidden_address' == True
      and the request user is neither owner or member of the organization """
  @wraps(func)
  def _impl(self, instance):
    # We pop address field to avoid AttributeError on default Serializer.to_representation
    for i, field in enumerate(self._readable_fields):
      if field.field_name == "address":
        address = self._readable_fields.pop(i)

    ret = func(self, instance)
    self._readable_fields.insert(i, address) # Put address back

    request = self.context["request"]

    # Check if user is organization member
    if instance.organization is not None:
      is_organization_member = (request.user in instance.organization.members.all())
    else:
      is_organization_member = False

    # Add address representation
    if request.user == instance.owner or is_organization_member:
      ret["address"] = self.fields["address"].to_representation(instance.address)
    else:
      ret["address"] = None

    return ret
  return _impl



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-26 16:48
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0027_auto_20170113_1746'),
    ]

    operations = [
        migrations.AlterField(
            model_name='apply',
            name='username',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='project',
            name='image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_uploads.UploadedImage', verbose_name='image'),
        ),
    ]



# -*- coding: utf-8 -*-
import sys

from django.core.management.base import BaseCommand
from django.utils import timezone
from ovp_projects.models import Project

class Command(BaseCommand):
  help = "Close projects which have a Job and end_date has already passed"

  def handle(self, *args, **options):
    projects = Project \
                 .objects \
                 .filter(closed=False, \
                         job__end_date__lt=timezone.now())
    print("Closing {} finished projects".format(projects.count()))
    projects.update(closed=True)



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-25 17:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0005_auto_20161025_1627'),
    ]

    operations = [
        migrations.RenameField(
            model_name='project',
            old_name='googleaddress',
            new_name='address',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-30 16:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0029_project_minimum_age'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='minimum_age',
            field=models.IntegerField(default=0, verbose_name='Minimum Age'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 16:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0023_auto_20170112_1417'),
    ]

    operations = [
        migrations.AddField(
            model_name='apply',
            name='phone',
            field=models.CharField(blank=True, max_length=30, null=True, verbose_name='phone'),
        ),
        migrations.AddField(
            model_name='apply',
            name='username',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='username'),
        ),
    ]



from django.db import models
from django.utils.translation import ugettext_lazy as _

class JobDate(models.Model):
  name = models.CharField(_('Label'), blank=True, null=True, max_length=20)
  start_date = models.DateTimeField(_('Start date'))
  end_date = models.DateTimeField(_('End date'))
  job = models.ForeignKey('Job', models.CASCADE, blank=True, null=True, related_name='dates', verbose_name=_('job'))

  def __str__(self):
    start_date = self.start_date and self.start_date.strftime("%d/%m/%Y %T") or '#'
    end_date = self.end_date and self.end_date.strftime("%d/%m/%Y %T") or '#'
    return "{}: {} ~ {}".format(self.name, start_date, end_date)

  class Meta:
    app_label = 'ovp_projects'
    verbose_name = _('job date')
    verbose_name_plural = _('job dates')


class Job(models.Model):
  project = models.OneToOneField('Project', blank=True, null=True)
  start_date = models.DateTimeField(_('Start date'), blank=True, null=True)
  end_date = models.DateTimeField(_('End date'), blank=True, null=True)
  can_be_done_remotely = models.BooleanField(_('This job can be done remotely'), default=False)

  def __str__(self):
    name = self.project and self.project.name or _('Unbound Job')
    start_date = self.start_date and self.start_date.strftime("%d/%m/%Y") or ''
    end_date = self.end_date and self.end_date.strftime("%d/%m/%Y") or ''
    return "{}: {} ~ {}".format(name, start_date, end_date)

  def update_dates(self):
    start = self.dates.all().order_by('start_date').first().start_date
    end   = self.dates.all().order_by('-end_date').first().end_date
    self.start_date = start
    self.end_date = end
    self.save()

  class Meta:
    app_label = 'ovp_projects'
    verbose_name = _('job')
    verbose_name_plural = _('jobs')




from django.core.exceptions import ObjectDoesNotExist
from django.db.models import Q

from ovp_projects.serializers import project as serializers
from ovp_projects import models
from ovp_projects import helpers
from ovp_projects.permissions import ProjectCreateOwnsOrIsOrganizationMember, OwnsOrIsOrganizationMember

from ovp_users import models as users_models

from rest_framework import decorators
from rest_framework import mixins
from rest_framework import viewsets
from rest_framework import permissions
from rest_framework import response
from rest_framework import status


class ProjectResourceViewSet(mixins.CreateModelMixin, mixins.RetrieveModelMixin, viewsets.GenericViewSet):
  """
  ProjectResourceViewSet resource endpoint
  """
  queryset = models.Project.objects.all()
  lookup_field = 'slug'
  lookup_value_regex = '[^/]+' # default is [^/.]+ - here we're allowing dots in the url slug field

  def create(self, request, *args, **kwargs):
    request.data['owner'] = request.user.pk

    serializer = self.get_serializer(data=request.data, context=self.get_serializer_context())
    serializer.is_valid(raise_exception=True)
    serializer.save()

    headers = self.get_success_headers(serializer.data)
    return response.Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)


  def partial_update(self, request, *args, **kwargs):
    """ We do not include the mixin as we want only PATCH and no PUT """
    instance = self.get_object()
    serializer = self.get_serializer(instance, data=request.data, partial=True, context=self.get_serializer_context())
    serializer.is_valid(raise_exception=True)
    serializer.save()

    if getattr(instance, '_prefetched_objects_cache', None): #pragma: no cover
      instance = self.get_object()
      serializer = self.get_serializer(instance)

    return response.Response(serializer.data)

  @decorators.detail_route(['POST'])
  def close(self, request, *args, **kwargs):
    project = self.get_object()
    project.closed = True
    project.save()
    serializer = self.get_serializer_class()(project, context=self.get_serializer_context())
    return response.Response(serializer.data)

  @decorators.list_route(['GET'])
  def manageable(self, request, *args, **kwargs):
    projects = models.Project.objects.filter(Q(owner=request.user) | Q(organization__owner=request.user) | Q(organization__members=request.user))

    serializer = self.get_serializer_class()(projects, many=True, context=self.get_serializer_context())
    return response.Response(serializer.data)

  @decorators.detail_route(['POST'])
  def apply(self, request, *args, **kwargs):
    data = request.data
    data.pop('user', None)

    project = self.get_object()
    data['project'] = project.id

    if request.user.is_authenticated():
      user = request.user
      data['username'] = user.name
      data['email'] = user.email
      data['phone'] = user.phone
      data['user'] = user.id

    try:
      existing_apply = models.Apply.objects.get(project=project, email=data['email'], canceled=True)
      existing_apply.canceled = False
      existing_apply.save()
    except ObjectDoesNotExist:
      apply_sr = self.get_serializer_class()(data=data, context=self.get_serializer_context())
      apply_sr.is_valid(raise_exception=True)
      apply_sr.save()

    return response.Response({'detail': 'Successfully applied.'}, status=status.HTTP_200_OK)

  @decorators.detail_route(['POST'])
  def unapply(self, request, *args, **kwargs):
    project = self.get_object()
    user = request.user

    try:
      existing_apply = models.Apply.objects.get(project=project, email=user.email, canceled=False)
      existing_apply.canceled = True
      existing_apply.save()
    except ObjectDoesNotExist:
      return response.Response({'detail': 'This is user is not applied to this project.'}, status=status.HTTP_400_BAD_REQUEST)

    return response.Response({'detail': 'Successfully unapplied.'}, status=status.HTTP_200_OK)

  @decorators.detail_route(['GET'])
  def applies(self, request, *arg, **kwargs):
    project = self.get_object()
    applies = models.Apply.objects.filter(project=project)

    serializer = self.get_serializer_class()(applies, many=True, context=self.get_serializer_context())

    return response.Response(serializer.data)


  # We need to override get_permissions and get_serializer_class to work
  # with multiple serializers and permissions
  def get_permissions(self):
    request = self.get_serializer_context()['request']
    if self.action == 'create':
      if helpers.get_settings().get('CAN_CREATE_PROJECTS_IN_ANY_ORGANIZATION', False):
        self.permission_classes = (permissions.IsAuthenticated, )
      else:
        self.permission_classes = (permissions.IsAuthenticated, ProjectCreateOwnsOrIsOrganizationMember)

    if self.action in ['applies', 'partial_update']:
      self.permission_classes = (permissions.IsAuthenticated, OwnsOrIsOrganizationMember, )

    if self.action == 'unapply':
      self.permission_classes = (permissions.IsAuthenticated, )

    if self.action == 'apply':
      if helpers.get_settings().get('UNAUTHENTICATED_APPLY', False):
        self.permission_classes = ()
      else:
        self.permission_classes = (permissions.IsAuthenticated, )

    if self.action == 'retrieve':
      self.permission_classes = ()

    if self.action == 'manageable':
      self.permission_classes = (permissions.IsAuthenticated, )

    if self.action == 'close':
      self.permission_classes = (permissions.IsAuthenticated, OwnsOrIsOrganizationMember, )

    return super(ProjectResourceViewSet, self).get_permissions()

  def get_serializer_class(self):
    if self.action in ['create', 'partial_update']:
      return serializers.ProjectCreateUpdateSerializer
    if self.action in ['apply', 'unapply']:
      return serializers.ApplyCreateSerializer
    if self.action == 'applies':
      return serializers.ApplyRetrieveSerializer
    if self.action == 'manageable':
      return serializers.ProjectRetrieveSerializer
    if self.action == 'close':
      return serializers.ProjectRetrieveSerializer

    return serializers.ProjectRetrieveSerializer



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-15 17:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0010_auto_20161102_2131'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='availability',
            options={'verbose_name': 'availability', 'verbose_name_plural': 'availabilities'},
        ),
        migrations.AlterModelOptions(
            name='job',
            options={'verbose_name': 'job', 'verbose_name_plural': 'jobs'},
        ),
        migrations.AlterModelOptions(
            name='jobdate',
            options={'verbose_name': 'job date', 'verbose_name_plural': 'job dates'},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'verbose_name': 'project', 'verbose_name_plural': 'projects'},
        ),
        migrations.AlterModelOptions(
            name='role',
            options={'verbose_name': 'volunteer role', 'verbose_name_plural': 'volunteer roles'},
        ),
        migrations.RemoveField(
            model_name='project',
            name='roles',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-30 16:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0030_auto_20170130_1630'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='hidden_address',
            field=models.BooleanField(default=False, verbose_name='Hidden address'),
        ),
    ]



from django.test import TestCase
from django.test import RequestFactory

from ovp_projects.models import Project
from ovp_projects.serializers.project import ProjectRetrieveSerializer
from ovp_projects.serializers.project import ProjectSearchSerializer

from ovp_users.models import User
from ovp_core.models import GoogleAddress
from ovp_organizations.models import Organization

class HiddenAddressTestCase(TestCase):
  def setUp(self):
    self.user = User.objects.create_user(email="test_user@gmail.com", password="test")
    self.second_user = User.objects.create_user(email="test_second_user@test.com", password="test")
    self.third_user = User.objects.create_user(email="test_third_user@test.com", password="test")

    organization = Organization(name="test", type=0, owner=self.user)
    organization.save()
    organization.members.add(self.second_user)

    address = GoogleAddress(typed_address="Rua. Teçaindá, 81")
    address.save()
    self.project = Project(name="test project", slug="test slug", details="abc", description="abc", owner=self.user, hidden_address=True, address=address, organization=organization)
    self.project.save()

    self.request = RequestFactory().get('/')


  def test_project_search_serializer_hides_address(self):
    """ Assert ProjectSearchSerializer hides adress if Project.hidden_address == True """
    self._assert_serializer_hides_address(ProjectSearchSerializer)

  def test_project_retrieve_serializer_hides_address(self):
    """ Assert ProjectRetrieveSerializer hides adress if Project.hidden_address == True """
    self._assert_serializer_hides_address(ProjectRetrieveSerializer)

  def _assert_serializer_hides_address(self, serializer_class):
    # Owner
    self.request.user = self.user
    serializer = serializer_class(self.project, context={"request": self.request})
    self.assertTrue(serializer.data["address"]["typed_address"] == "Rua. Teçaindá, 81")
    self.assertTrue(serializer.data["hidden_address"] == True)

    # Organization member
    self.request.user = self.second_user
    serializer = serializer_class(self.project, context={"request": self.request})
    self.assertTrue(serializer.data["address"]["typed_address"] == "Rua. Teçaindá, 81")
    self.assertTrue(serializer.data["hidden_address"] == True)

    # Non member
    self.request.user = self.third_user
    serializer = serializer_class(self.project, context={"request": self.request})
    self.assertTrue(serializer.data["address"] == None)
    self.assertTrue(serializer.data["hidden_address"] == True)



from django.test import TestCase
from django.core import mail
from django.test.utils import override_settings

from ovp_core.helpers import get_email_subject, is_email_enabled
from ovp_users.models import User
from ovp_projects.models import Project, Apply

class TestEmailTriggers(TestCase):
  def test_project_creation_trigger_email(self):
    """Assert that email is triggered when creating a project"""
    user = User.objects.create_user(email="test_project@project.com", password="test_project")
    project = Project(name="test project", slug="test project", details="abc", description="abc", owner=user)

    mail.outbox = [] # Mails sent before creating don't matter
    project.save()

    if is_email_enabled("projectCreated"):
      self.assertTrue(len(mail.outbox) == 1)
      self.assertTrue(mail.outbox[0].subject == get_email_subject("projectCreated", "Project created"))
    else: # pragma: no cover
      self.assertTrue(len(mail.outbox) == 0)

  def test_project_publishing_trigger_email(self):
    """Assert that email is triggered when publishing a project"""
    user = User.objects.create_user(email="test_project@project.com", password="test_project")
    project = Project(name="test project", slug="test project", details="abc", description="abc", owner=user)
    project.save()

    mail.outbox = [] # Mails sent before publishing don't matter
    project.published = True
    project.save()


    if is_email_enabled("projectPublished"): # pragma: no cover
      self.assertTrue(len(mail.outbox) == 1)
      self.assertTrue(mail.outbox[0].subject == get_email_subject("projectPublished", "Project published"))
    else: # pragma: no cover
      self.assertTrue(len(mail.outbox) == 0)


  def test_project_closing_trigger_email(self):
    """Assert that email is triggered when closing a project"""
    user = User.objects.create_user(email="test_project@project.com", password="test_project")
    project = Project(name="test project", slug="test project", details="abc", description="abc", owner=user)
    project.save()

    mail.outbox = [] # Mails sent before closing don't matter
    project.closed = True
    project.save()


    if is_email_enabled("projectClosed"): # pragma: no cover
      self.assertTrue(len(mail.outbox) == 1)
      self.assertTrue(mail.outbox[0].subject == get_email_subject("projectClosed", "Project closed"))
    else: # pragma: no cover
      self.assertTrue(len(mail.outbox) == 0)


  def test_apply_trigger_email(self):
    """Assert that applying to project trigger one email to volunteer and one to project owner"""
    user = User.objects.create_user(email="test_project@project.com", password="test_project")
    volunteer = User.objects.create_user(email="test_volunteer@project.com", password="test_volunteer")
    project = Project(name="test project", slug="test project", details="abc", description="abc", owner=user)
    project.save()

    mail.outbox = [] # Mails sent before applying don't matter
    apply = Apply(project=project, user=volunteer, email=volunteer.email)
    apply.save()

    recipients = [x.to[0] for x in mail.outbox]
    subjects = [x.subject for x in mail.outbox]

    if is_email_enabled("volunteerApplied-ToVolunteer"): # pragma: no cover
      self.assertTrue(get_email_subject("volunteerApplied-ToVolunteer", "Applied to project") in subjects)
      self.assertTrue("test_project@project.com" in recipients)

    if is_email_enabled("volunteerApplied-ToOwner"): # pragma: no cover
      self.assertTrue(get_email_subject("volunteerApplied-ToOwner", "New volunteer") in subjects)
      self.assertTrue("test_volunteer@project.com" in recipients)


  def test_unapply_trigger_email(self):
    """Assert that applying to project trigger one email to volunteer and one to project owner"""
    user = User.objects.create_user(email="test_project@project.com", password="test_project")
    volunteer = User.objects.create_user(email="test_volunteer@project.com", password="test_volunteer")
    project = Project(name="test project", slug="test project", details="abc", description="abc", owner=user)
    project.save()

    mail.outbox = [] # Mails sent before applying don't matter
    apply = Apply(project=project, user=volunteer, email=volunteer.email, canceled=True)
    apply.save()

    recipients = [x.to[0] for x in mail.outbox]
    subjects = [x.subject for x in mail.outbox]

    if is_email_enabled("volunteerUnapplied-ToVolunteer"): # pragma: no cover
      self.assertTrue(get_email_subject("volunteerUnapplied-ToVolunteer", "Unapplied from project") in subjects)
      self.assertTrue("test_project@project.com" in recipients)

    if is_email_enabled("volunteerUnapplied-ToOwner"): # pragma: no cover
      self.assertTrue(get_email_subject("volunteerUnapplied-ToOwner", "Volunteer unapplied from project") in subjects)
      self.assertTrue("test_volunteer@project.com" in recipients)



from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from ovp_projects.models import Work


class WorkAdmin(admin.ModelAdmin):
  fields = [
  	('id', 'project'),
  	'weekly_hours',
  	'description',
  	'can_be_done_remotely',
  ]

  list_display = [
  	'id', 'project', 'weekly_hours', 'can_be_done_remotely'
  ]

  list_filter = []

  list_editable = ['can_be_done_remotely']

  search_fields = ['project__name', 'project__organization__name']

  readonly_fields = ['id']

  raw_id_fields = []


class WorkInline(admin.TabularInline):
  model = Work


admin.site.register(Work, WorkAdmin)





# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-15 23:02
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ovp_projects', '0013_project_roles'),
    ]

    operations = [
        migrations.CreateModel(
            name='Apply',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(max_length=30, verbose_name='name')),
                ('date', models.DateTimeField(auto_now_add=True)),
                ('canceled', models.BooleanField(default=False, verbose_name='Canceled')),
                ('canceled_date', models.DateTimeField(blank=True, null=True, verbose_name='Canceled date')),
                ('email', models.CharField(blank=True, max_length=200, null=True, verbose_name='Email')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ovp_projects.Project')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'applies',
                'verbose_name': 'apply',
            },
        ),
    ]



from rest_framework import permissions
from ovp_organizations.models import Organization


class ProjectCreateOwnsOrIsOrganizationMember(permissions.BasePermission):
  def has_permission(self, request, view):
    organization_pk = request.data.get('organization', None)

    if not organization_pk:
      return True

    if not isinstance(organization_pk, int):
      return True # Should fail on validator

    try:
      organization = Organization.objects.get(pk=organization_pk)
      if organization.owner == request.user or request.user in organization.members.all():
        return True
    except Organization.DoesNotExist: #pragma: no cover
      pass
    return False


class OwnsOrIsOrganizationMember(permissions.BasePermission):
  def has_object_permission(self, request, view, obj):
    if request.user.is_authenticated:
      if obj.owner == request.user:
        return True
      if obj.organization:
        if request.user in obj.organization.members.all():
          return True
    return False



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 18:55
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0024_auto_20170112_1644'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='max_applies',
            field=models.IntegerField(default=1),
        ),
        migrations.AddField(
            model_name='project',
            name='public_project',
            field=models.BooleanField(default=True, verbose_name='Public'),
        ),
        migrations.AlterField(
            model_name='project',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='owner'),
        ),
    ]



from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from ovp_projects.models import JobDate


class JobDateInline(admin.TabularInline):
  model = JobDate


class JobDateAdmin(admin.ModelAdmin):
  list_display = ['id', 'start_date', 'end_date']
  raw_id_fields = ['job']


admin.site.register(JobDate, JobDateAdmin)





# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-07 17:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0020_work_can_be_done_remotely'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='max_applies_from_roles',
            field=models.IntegerField(default=0),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-02 21:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0008_project_organization'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='image',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_uploads.UploadedImage'),
        ),
    ]
